@@ -1,7 +1,7 @@
 
 from lazyme.dating import daterange, dates_in_quarter
 
-from lazyme.fileio import find_files
+from lazyme.fileio import find_files, open_two
 
 from lazyme.iterate import per_section, per_chunk, per_window
 from lazyme.iterate import zigzag
@@ -14,6 +14,6 @@ from lazyme.timing import retry
 
 from lazyme.wikipedia import iter_paragraph as iter_wiki
 
-from lazyme.data import get_content, norvig_bigtxt
+from lazyme.data import get_content, norvig_bigtxt, getsize
 
-__version__ = '0.0.23'
+__version__ = '0.0.27'
