@@ -18,3 +18,8 @@ def find_files(dir_path, extension="*"):
         for root, dirnames, filenames in os.walk(dir_path):
             for filename in fnmatch.filter(filenames, extension):
                 yield os.path.join(root, filename)
+
+def open_two(filename1, filename2):
+    with open(filename1) as fin, open(filename2) as fin2:
+        for line1, line2 in zip(fin1, fin2):
+            yield line1, line2
